summaryrefslogtreecommitdiff
path: root/src/tree_map.h
diff options
context:
space:
mode:
authoralberth <alberth@openttd.org>2010-07-31 21:02:56 +0000
committeralberth <alberth@openttd.org>2010-07-31 21:02:56 +0000
commita825b4fa5f159604f9f61bafa21b75a22d8944f5 (patch)
tree7a9c837d047157b4e2d0d068c0c3462c7a643ef9 /src/tree_map.h
parentadf94b85297b6a11989617eaa1081c7b1da08b62 (diff)
downloadopenttd-a825b4fa5f159604f9f61bafa21b75a22d8944f5.tar.xz
(svn r20266) -Doc: Mostly typo fixes, a few doxygen-related improvements.
Diffstat (limited to 'src/tree_map.h')
-rw-r--r--src/tree_map.h15
1 files changed, 7 insertions, 8 deletions
diff --git a/src/tree_map.h b/src/tree_map.h
index c5cfb921a..53e6bc427 100644
--- a/src/tree_map.h
+++ b/src/tree_map.h
@@ -33,18 +33,17 @@ enum TreeType {
TREE_INVALID = 0xFF, ///< An invalid tree
};
/*
* Counts the number of treetypes for each landscape.
*
* This list contains the counts of different treetypes for each landscape. This list contains
* 5 entries instead of 4 (as there are only 4 landscape types) as the sub tropic landscape
* has two types of area, one for normal trees and one only for cacti.
*/
-static const uint TREE_COUNT_TEMPERATE = TREE_SUB_ARCTIC - TREE_TEMPERATE; ///< number of treetypes on a temperate map
-static const uint TREE_COUNT_SUB_ARCTIC = TREE_RAINFOREST - TREE_SUB_ARCTIC; ///< number of treetypes on a sub arctic map
-static const uint TREE_COUNT_RAINFOREST = TREE_CACTUS - TREE_RAINFOREST; ///< number of treetypes for the 'rainforest part' of a sub-tropic map
-static const uint TREE_COUNT_SUB_TROPICAL = TREE_TOYLAND - TREE_SUB_TROPICAL; ///< number of treetypes for the 'sub-tropic part' of a sub-tropic map
-static const uint TREE_COUNT_TOYLAND = 9; ///< number of treetypes on a toyland map
+static const uint TREE_COUNT_TEMPERATE = TREE_SUB_ARCTIC - TREE_TEMPERATE; ///< number of tree types on a temperate map.
+static const uint TREE_COUNT_SUB_ARCTIC = TREE_RAINFOREST - TREE_SUB_ARCTIC; ///< number of tree types on a sub arctic map.
+static const uint TREE_COUNT_RAINFOREST = TREE_CACTUS - TREE_RAINFOREST; ///< number of tree types for the 'rainforest part' of a sub-tropic map.
+static const uint TREE_COUNT_SUB_TROPICAL = TREE_TOYLAND - TREE_SUB_TROPICAL; ///< number of tree types for the 'sub-tropic part' of a sub-tropic map.
+static const uint TREE_COUNT_TOYLAND = 9; ///< number of tree types on a toyland map.
/**
* Enumeration for ground types of tiles with trees.
@@ -33,18 +33,17 @@ enum TreeType {
TREE_INVALID = 0xFF, ///< An invalid tree
};
-/*
- * Counts the number of treetypes for each landscape.
+/* Counts the number of tree types for each landscape.
*
@@ -33,18 +33,17 @@ enum TreeType {
*
- * This list contains the counts of different treetypes for each landscape. This list contains
+ * This list contains the counts of different tree types for each landscape. This list contains
* 5 entries instead of 4 (as there are only 4 landscape types) as the sub tropic landscape
* has two types of area, one for normal trees and one only for cacti.